@@ -1,3 +1,4 @@
+from requestsWS.session import Session
 from websocket import create_connection
 import json as JSON
 
@@ -109,14 +110,11 @@ class post:
     def json(self):
         return JSON.loads(self.text)
 
-def isRunning(wsUrl):
-    response = True
-    try:
-        connectionsKept[wsUrl]
-    except Exception:
-        response = False
 
-    return response
+def isRunning(wsUrl):
+    if wsUrl in connectionsKept:
+        return True
+    return False
 
 def heartbeat(wsUrl, interval, payload):
     time.sleep(interval)
@@ -139,4 +137,4 @@ def closeConnection(wsUrl):
     except Exception:
         pass
     time.cancel()
-    ws.close()
+    ws.close()
\ No newline at end of file
